@@ -23,16 +23,16 @@ users = {
 
 @auth.verify_password
 def verify_password(username, password):
-    if username in users:
-        return check_password_hash(users.get(username), password)
-    return False
+    if username in users and check_password_hash(users.get(username),
+                                                 password):
+        return username
 
 
 @app.route('/')
 @auth.login_required
 def index():
-    return "Hello, %s!" % auth.username()
+    return "Hello, %s!" % auth.current_user()
 
 
 if __name__ == '__main__':
-    app.run()
+    app.run(debug=True, host='0.0.0.0')
